aboutsummaryrefslogtreecommitdiffstats
path: root/wirish/time.h
diff options
context:
space:
mode:
Diffstat (limited to 'wirish/time.h')
-rw-r--r--wirish/time.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/wirish/time.h b/wirish/time.h
index fad47a4..c3dfe2d 100644
--- a/wirish/time.h
+++ b/wirish/time.h
@@ -59,10 +59,10 @@ static inline uint32 micros(void) {
nvic_globalirq_enable();
- /* MAPLE_RELOAD_VAL is 1 less than the number of cycles it actually
- takes to complete a systick reload */
+ /* SYSTICK_RELOAD_VAL is 1 less than the number of cycles it
+ actually takes to complete a SysTick reload */
res = (ms * US_PER_MS) +
- (MAPLE_RELOAD_VAL + 1 - cycle_cnt)/CYCLES_PER_MICROSECOND;
+ (SYSTICK_RELOAD_VAL + 1 - cycle_cnt)/CYCLES_PER_MICROSECOND;
return res;
}